package com.lantone.qc.kernel.catalogue.firstcourserecord;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.BeHospitalizedDoc;
import com.lantone.qc.pub.model.entity.Diag;
import com.lantone.qc.pub.model.label.DiagLabel;
import com.lantone.qc.pub.model.label.PastLabel;
import com.lantone.qc.pub.model.label.PresentLabel;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;

/**
 * @ClassName : FIRC0095
 * @Description : 初步诊断不完整
 * 和入院记录的初步诊断比较
 * @Author : 楼辉荣
 * @Date: 2020-03-06 17:28
 */
@Component
public class FIRC0095 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        //        FirstCourseRecordDoc firstCourseRecordDoc = inputInfo.getFirstCourseRecordDoc();
        BeHospitalizedDoc beHospitalizedDoc = inputInfo.getBeHospitalizedDoc();
        if (beHospitalizedDoc == null) {
            status.set("0");
            return;
        }
        //DiagLabel initialDiagLabel = firstCourseRecordDoc.getInitialDiagLabel();
        PresentLabel presentLabel = beHospitalizedDoc.getPresentLabel();
        PastLabel pastLabel = beHospitalizedDoc.getPastLabel();
        DiagLabel initialDiagLabel = beHospitalizedDoc.getInitialDiagLabel();

        if (initialDiagLabel == null) {
            status.set("0");
            return;
        }
        List<String> bhDiags = new ArrayList<>();
        /* 现病史诊断 */
        if (presentLabel != null && presentLabel.getDiags() != null) {
            List<Diag> presentDiags = presentLabel.getDiags();
            copyDiag(presentDiags, bhDiags);
        }
        /* 既往史诊断 */
        if (pastLabel != null && pastLabel.getDiags() != null) {
            List<Diag> pastDiags = pastLabel.getDiags();
            copyDiag(pastDiags, bhDiags);
        }
        /* 初步诊断 */
        List<Diag> diags = initialDiagLabel.getDiags();
        List<String> initDiags = new ArrayList<>();
        if (diags != null) {
            copyDiag(diags, initDiags);
        }

        //List<Diag> diags1 = initialDiagLabel1.getDiags();
        /* 初步诊断包含现病史诊断和既往史诊断 */
        if (initDiags.containsAll(bhDiags)) {
            status.set("0");
        }
    }

    private void copyDiag(List<Diag> diags, List<String> diagList) {
        String hospitalDiagName, name;
        for (Diag diag : diags) {
            if (diag.getNegative() != null) {
                continue;
            }
            hospitalDiagName = diag.getHospitalDiagName();
            name = diag.getName();
            if (StringUtil.isNotBlank(hospitalDiagName)) {
                diagList.add(hospitalDiagName);
            } else if (StringUtil.isNotBlank(name)) {
                diagList.add(name);
            }
        }
    }
}
