package com.lantone.qc.kernel.catalogue.threelevelward;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.util.CatalogueUtil;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.DeathCaseDiscussDoc;
import com.lantone.qc.pub.model.doc.DeathRecordDoc;
import com.lantone.qc.pub.model.doc.ThreeLevelWardDoc;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @ClassName : THR0144
 * @Description : 患者出院前无主治医师/副主任医师/主任医师/科主任同意出院的病程记录
 * @Author : 胡敬
 * @Date: 2020-03-19 17:20
 */
@Component
public class THR0144 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        if (inputInfo.getThreeLevelWardDocs().size() == 0) {
            status.set("0");
            return;
        }
        DeathRecordDoc deathRecordDoc = inputInfo.getDeathRecordDoc();
        DeathCaseDiscussDoc deathCaseDiscussDoc = inputInfo.getDeathCaseDiscussDoc();
        if (deathRecordDoc != null || deathCaseDiscussDoc != null){
            status.set("0");
            return;
        }
        List<ThreeLevelWardDoc> allDoctorWradDocs = inputInfo.getThreeLevelWardDocs().get(0).getAllDoctorWradDocs();
        if (allDoctorWradDocs.size() == 0) {
            status.set("0");
            return;
        }
        ThreeLevelWardDoc lastWardDoc = allDoctorWradDocs.get(allDoctorWradDocs.size() - 1);
        Map<String, String> structureMap = lastWardDoc.getStructureMap();
        String conditionRecord = structureMap.get("病情记录");
        String treatmentPlan = structureMap.get("治疗计划和措施");
        String title = structureMap.get("查房标题");
        conditionRecord = StringUtil.isBlank(conditionRecord) ? "" : conditionRecord;
        treatmentPlan = StringUtil.isBlank(treatmentPlan) ? "" : treatmentPlan;
        //主任或主治查房 标题需要包含“主任”或“主治”，内容需要包含“出院”
        if ((conditionRecord.contains("出院") || treatmentPlan.contains("出院") || conditionRecord.contains("转上级医院"))
                && StringUtil.isNotBlank(title)
                && (CatalogueUtil.subTitle(title).contains(Content.attend) || CatalogueUtil.subTitle(title).contains(Content.director))) {
            status.set("0");
        }
        //普通查房 内容需要包含“上级”和“出院”
        if (StringUtil.isBlank(title)
                || (title.contains("日常查房记录") || title.contains("普通查房记录") || title.contains("日常病程记录"))
                && conditionRecord.contains("上级")
                && (conditionRecord.contains("出院") || treatmentPlan.contains("出院"))) {
            status.set("0");
        }
    }
}